Documentation
¶
Index ¶
- func ApiAuthKnightCallback(endpoint string) string
- func ApiImpersonateStart(endpoint string) string
- func ApiImpersonateStop(endpoint string) string
- func ApiLogin(endpoint string) string
- func ApiLoginCodeVerify(endpoint string) string
- func ApiLogout(endpoint string) string
- func ApiPasswordReset(endpoint string) string
- func ApiPasswordRestore(endpoint string) string
- func ApiRegister(endpoint string) string
- func ApiRegisterCodeVerify(endpoint string) string
- func Join(endpoint, uri string) string
- func Login(endpoint string) string
- func LoginCodeVerify(endpoint string) string
- func Logout(endpoint string) string
- func PasswordReset(endpoint string) string
- func PasswordRestore(endpoint string) string
- func Register(endpoint string) string
- func RegisterCodeVerify(endpoint string) string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ApiAuthKnightCallback ¶ added in v0.35.0
func ApiImpersonateStart ¶ added in v0.33.0
func ApiImpersonateStop ¶ added in v0.33.0
func ApiLoginCodeVerify ¶
func ApiPasswordReset ¶
func ApiPasswordRestore ¶
func ApiRegister ¶
func ApiRegisterCodeVerify ¶
func Join ¶
Join combines the base endpoint and a relative URI in a consistent way. If the endpoint already has a trailing slash, the URI is appended directly; otherwise a slash is inserted between them.
func LoginCodeVerify ¶
func PasswordReset ¶
func PasswordRestore ¶
func RegisterCodeVerify ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.